@@ -44,7 +44,7 @@ def _hist_gray(gray_img, bins, lower_bound, upper_bound, mask=None):
         pixels = len(np.where(mask > 0)[0])
         # apply plant shaped mask to image
         params.debug = None
-        mask1 = binary_thresholding(mask, 0, 255, 'light')
+        mask1 = binary_threshold(mask, 0, 255, 'light')
         mask1 = (mask1 / 255)
         masked = np.where(mask1 != 0, gray_img, min_val - 5000)
 
