@@ -7,16 +7,7 @@ from LivestockCV.core import fatal_error
 
 
 def print_image(img, filename):
-    """Save image to file.
 
-    Inputs:
-    img      = image object
-    filename = name of file to save image to
-
-    :param img: numpy.ndarray
-    :param filename: string
-    :return:
-    """
 
     # Print numpy array type images
     image_type = type(img)
